# PhDictionary | Best tool for language learning

This tool can help you to provide better understanding of foreign word using examples, definitions and translation.

You can collect all the words that you want to get acquainted with and just put a txt file into this tool to generate Word documents like this:

![Alt text](/examples/def.png?raw=true "Definition")

With examples:

![Alt text](/examples/def-e.png?raw=true "Definition_examples")

And translate from French to English:


![Alt text](/examples/fr-eng.png?raw=true "Definition_examples")
[Github-flavored Markdown](https://github.com/RediIVIideR/phdictionary/blob/main/README.md)